from sqlalchemy import Column, Integer, String, DateTime, Boolean, Text, Float, ForeignKey
from sqlalchemy.orm import relationship
from datetime import datetime

from app.db.base import Base

class CarbonOffset(Base):
    __tablename__ = "carbon_offsets"

    id = Column(Integer, primary_key=True, index=True)
    serial_number = Column(String, unique=True, nullable=False)
    vintage_year = Column(Integer, nullable=False)
    quantity = Column(Integer, nullable=False)  # Number of credits
    status = Column(String, default="available")  # "available", "sold", "retired"
    
    # Blockchain information
    token_id = Column(String, unique=True, nullable=True)
    blockchain_hash = Column(String, nullable=True)
    
    # Timestamps
    created_at = Column(DateTime, default=datetime.utcnow)
    updated_at = Column(DateTime, default=datetime.utcnow, onupdate=datetime.utcnow)
    
    # Foreign keys
    project_id = Column(Integer, ForeignKey("carbon_projects.id"), nullable=False)
    
    # Relationships
    project = relationship("CarbonProject", back_populates="offsets")
    transactions = relationship("Transaction", back_populates="offset")