from sqlalchemy import Column, Integer, String, DateTime, Boolean, Text, Float, ForeignKey
from sqlalchemy.orm import relationship
from datetime import datetime

from app.db.base import Base

class CarbonProject(Base):
    __tablename__ = "carbon_projects"

    id = Column(Integer, primary_key=True, index=True)
    title = Column(String, nullable=False)
    description = Column(Text, nullable=False)
    location = Column(String, nullable=False)
    project_type = Column(String, nullable=False)  # "forestry", "renewable_energy", "waste_management", etc.
    methodology = Column(String, nullable=False)  # Certification methodology used
    
    # Carbon offset details
    total_credits_available = Column(Integer, nullable=False)
    credits_sold = Column(Integer, default=0)
    price_per_credit = Column(Float, nullable=False)  # Price in USD
    
    # Project timeline
    start_date = Column(DateTime, nullable=False)
    end_date = Column(DateTime, nullable=False)
    
    # Verification and status
    verification_status = Column(String, default="pending")  # "pending", "verified", "rejected"
    verification_document_url = Column(String, nullable=True)
    is_active = Column(Boolean, default=True)
    
    # Blockchain information
    contract_address = Column(String, nullable=True)
    token_id = Column(String, nullable=True)
    
    # Timestamps
    created_at = Column(DateTime, default=datetime.utcnow)
    updated_at = Column(DateTime, default=datetime.utcnow, onupdate=datetime.utcnow)
    
    # Foreign keys
    developer_id = Column(Integer, ForeignKey("users.id"), nullable=False)
    
    # Relationships
    developer = relationship("User", back_populates="projects")
    offsets = relationship("CarbonOffset", back_populates="project")