from sqlalchemy import Column, Integer, String, DateTime, Boolean, Text
from sqlalchemy.orm import relationship
from datetime import datetime

from app.db.base import Base

class User(Base):
    __tablename__ = "users"

    id = Column(Integer, primary_key=True, index=True)
    email = Column(String, unique=True, index=True, nullable=False)
    hashed_password = Column(String, nullable=False)
    full_name = Column(String, nullable=False)
    user_type = Column(String, nullable=False)  # "developer" or "buyer"
    is_active = Column(Boolean, default=True)
    created_at = Column(DateTime, default=datetime.utcnow)
    updated_at = Column(DateTime, default=datetime.utcnow, onupdate=datetime.utcnow)
    
    # Blockchain wallet information
    wallet_address = Column(String, unique=True, nullable=True)
    wallet_public_key = Column(Text, nullable=True)
    
    # Relationships
    projects = relationship("CarbonProject", back_populates="developer")
    transactions = relationship("Transaction", back_populates="buyer")