from pydantic import BaseModel, EmailStr
from typing import Optional
from datetime import datetime

class UserBase(BaseModel):
    email: EmailStr
    full_name: str
    user_type: str

class UserCreate(UserBase):
    password: str

class UserLogin(BaseModel):
    email: EmailStr
    password: str

class UserResponse(UserBase):
    id: int
    is_active: bool
    created_at: datetime
    wallet_address: Optional[str] = None
    
    class Config:
        from_attributes = True

class Token(BaseModel):
    access_token: str
    token_type: str

class WalletLinkRequest(BaseModel):
    wallet_address: str

class WalletResponse(BaseModel):
    success: bool
    wallet_linked: bool
    wallet_address: Optional[str] = None
    balance: Optional[float] = None
    message: Optional[str] = None